<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="cs_CZ" sourcelanguage="">
<context>
    <name>LogPassDialog</name>
    <message>
        <location filename="retext.py" line="175"/>
        <source>Enter your Google account data</source>
        <translation>Zadejte své přihlašovací údaje k účtu Google</translation>
    </message>
    <message>
        <location filename="retext.py" line="184"/>
        <source>Username</source>
        <translation>Uživatelské jméno</translation>
    </message>
    <message>
        <location filename="retext.py" line="185"/>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
</context>
<context>
    <name>ReTextWindow</name>
    <message>
        <location filename="retext.py" line="1330"/>
        <source>New document</source>
        <translation>Nový dokument</translation>
    </message>
    <message>
        <location filename="retext.py" line="245"/>
        <source>File toolbar</source>
        <translation>Nástrojová lišta Soubor</translation>
    </message>
    <message>
        <location filename="retext.py" line="247"/>
        <source>Edit toolbar</source>
        <translation>Nástrojová lišta Úpravy</translation>
    </message>
    <message>
        <location filename="retext.py" line="251"/>
        <source>New</source>
        <translation>Nový</translation>
    </message>
    <message>
        <location filename="retext.py" line="253"/>
        <source>Open</source>
        <translation>Otevřít</translation>
    </message>
    <message>
        <location filename="retext.py" line="255"/>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <location filename="retext.py" line="258"/>
        <source>Save as</source>
        <translation>Uložit jako</translation>
    </message>
    <message>
        <location filename="retext.py" line="260"/>
        <source>Print</source>
        <translation>Tisknout</translation>
    </message>
    <message>
        <location filename="retext.py" line="262"/>
        <source>Print preview</source>
        <translation>Náhled tisku</translation>
    </message>
    <message>
        <location filename="retext.py" line="264"/>
        <source>View HTML code</source>
        <translation>Zobrazit HTML kód</translation>
    </message>
    <message>
        <location filename="retext.py" line="265"/>
        <source>Change default font</source>
        <translation>Změnit výchozí písmo</translation>
    </message>
    <message>
        <location filename="retext.py" line="270"/>
        <source>Preview</source>
        <translation>Náhled</translation>
    </message>
    <message>
        <location filename="retext.py" line="279"/>
        <source>Live preview</source>
        <translation>Průběžný náhled</translation>
    </message>
    <message>
        <location filename="retext.py" line="288"/>
        <source>Other formats</source>
        <translation>Jiné formáty</translation>
    </message>
    <message>
        <location filename="retext.py" line="294"/>
        <source>Quit</source>
        <translation>Ukončit</translation>
    </message>
    <message>
        <location filename="retext.py" line="297"/>
        <source>Undo</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <location filename="retext.py" line="299"/>
        <source>Redo</source>
        <translation>Znovu</translation>
    </message>
    <message>
        <location filename="retext.py" line="301"/>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <location filename="retext.py" line="303"/>
        <source>Cut</source>
        <translation>Vyjmout</translation>
    </message>
    <message>
        <location filename="retext.py" line="305"/>
        <source>Paste</source>
        <translation>Vložit</translation>
    </message>
    <message>
        <location filename="retext.py" line="325"/>
        <source>Plain text</source>
        <translation>Prostý text</translation>
    </message>
    <message>
        <location filename="retext.py" line="413"/>
        <source>Open recent</source>
        <translation>Otevřít nedávné</translation>
    </message>
    <message>
        <location filename="retext.py" line="334"/>
        <source>Generate webpages</source>
        <translation>Generovat webové stránky</translation>
    </message>
    <message>
        <location filename="retext.py" line="335"/>
        <source>Show</source>
        <translation>Zobrazit</translation>
    </message>
    <message>
        <location filename="retext.py" line="347"/>
        <source>About Qt</source>
        <translation>O Qt</translation>
    </message>
    <message>
        <location filename="retext.py" line="373"/>
        <source>Save to Google Docs</source>
        <translation>Uložit na Google Docs</translation>
    </message>
    <message>
        <location filename="retext.py" line="380"/>
        <source>Tags</source>
        <translation>Značky</translation>
    </message>
    <message>
        <location filename="retext.py" line="384"/>
        <source>Symbols</source>
        <translation>Entity</translation>
    </message>
    <message>
        <location filename="retext.py" line="408"/>
        <source>File</source>
        <translation>Soubor</translation>
    </message>
    <message>
        <location filename="retext.py" line="409"/>
        <source>Edit</source>
        <translation>Upravit</translation>
    </message>
    <message>
        <location filename="retext.py" line="410"/>
        <source>Help</source>
        <translation>Nápověda</translation>
    </message>
    <message>
        <location filename="retext.py" line="416"/>
        <source>Directory</source>
        <translation>Složka</translation>
    </message>
    <message>
        <location filename="retext.py" line="424"/>
        <source>Export</source>
        <translation>Exportovat</translation>
    </message>
    <message>
        <location filename="retext.py" line="526"/>
        <source>Only HTML formatting will be available.</source>
        <translation>Bude dostupné pouze HTML formátování.</translation>
    </message>
    <message>
        <location filename="retext.py" line="813"/>
        <source>Please, save the file somewhere.</source>
        <translation>Soubor, prosím, někam uložte.</translation>
    </message>
    <message>
        <location filename="retext.py" line="800"/>
        <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
        <translation>Webové stránky uloženy do složky &lt;code&gt;html&lt;/code&gt;.</translation>
    </message>
    <message>
        <location filename="retext.py" line="929"/>
        <source>Supported files</source>
        <translation>Podporované soubory</translation>
    </message>
    <message>
        <location filename="retext.py" line="929"/>
        <source>All files (*)</source>
        <translation>Všechny soubory (*)</translation>
    </message>
    <message>
        <location filename="retext.py" line="984"/>
        <source>Plain text (*.txt)</source>
        <translation>Prostý text (*.txt)</translation>
    </message>
    <message>
        <location filename="retext.py" line="1071"/>
        <source>Save file</source>
        <translation>Uložit soubor</translation>
    </message>
    <message>
        <location filename="retext.py" line="1062"/>
        <source>Export document to ODT</source>
        <translation>Exportovat dokument do ODT</translation>
    </message>
    <message>
        <location filename="retext.py" line="1062"/>
        <source>OpenDocument text files (*.odt)</source>
        <translation>Textové soubory OpenDocument (*.odt)</translation>
    </message>
    <message>
        <location filename="retext.py" line="1071"/>
        <source>HTML files (*.html *.htm)</source>
        <translation>Soubory HTML (*.html *.htm)</translation>
    </message>
    <message>
        <location filename="retext.py" line="1094"/>
        <source>Export document to PDF</source>
        <translation>Exportovat dokument do PDF</translation>
    </message>
    <message>
        <location filename="retext.py" line="1094"/>
        <source>PDF files (*.pdf)</source>
        <translation>Soubory PDF (*.pdf)</translation>
    </message>
    <message>
        <location filename="retext.py" line="1109"/>
        <source>Print document</source>
        <translation>Tisknout dokument</translation>
    </message>
    <message>
        <location filename="retext.py" line="1158"/>
        <source>This function is not available in Plain text mode!</source>
        <translation>Tato funkce není k dispozici v režimu Prostý text!</translation>
    </message>
    <message>
        <location filename="retext.py" line="1161"/>
        <source>Select type</source>
        <translation>Vyberte typ</translation>
    </message>
    <message>
        <location filename="retext.py" line="1128"/>
        <source>Export document</source>
        <translation>Exportovat dokument</translation>
    </message>
    <message>
        <location filename="retext.py" line="1224"/>
        <source>Incorrect user name or password!</source>
        <translation>Nesprávné uživatelské jméno nebo heslo!</translation>
    </message>
    <message>
        <location filename="retext.py" line="1299"/>
        <source>The document has been modified.
Do you want to save your changes?</source>
        <translation>Dokument byl změněn. Chcete uložit své změny?</translation>
    </message>
    <message>
        <location filename="retext.py" line="1337"/>
        <source>HTML code</source>
        <translation>HTML kód</translation>
    </message>
    <message>
        <location filename="retext.py" line="315"/>
        <source>Enable</source>
        <translation>Povolit</translation>
    </message>
    <message>
        <location filename="retext.py" line="316"/>
        <source>Set locale</source>
        <translation>Nastavit lokalizaci</translation>
    </message>
    <message>
        <location filename="retext.py" line="450"/>
        <source>Spell check</source>
        <translation>Kontrola pravopisu</translation>
    </message>
    <message>
        <location filename="retext.py" line="726"/>
        <source>Enter locale name (example: en_US)</source>
        <translation>Zadejte název lokalizace (např.: cs_CZ)</translation>
    </message>
    <message>
        <location filename="retext.py" line="281"/>
        <source>Fullscreen mode</source>
        <translation>Celoobrazovkový režim</translation>
    </message>
    <message>
        <location filename="retext.py" line="249"/>
        <source>Search toolbar</source>
        <translation>Nástrojová lišta Najít</translation>
    </message>
    <message>
        <location filename="retext.py" line="266"/>
        <source>Find text</source>
        <translation>Najít text</translation>
    </message>
    <message>
        <location filename="retext.py" line="336"/>
        <source>Next</source>
        <translation>Následující</translation>
    </message>
    <message>
        <location filename="retext.py" line="337"/>
        <source>Previous</source>
        <translation>Předchozí</translation>
    </message>
    <message>
        <location filename="retext.py" line="458"/>
        <source>Default editing mode</source>
        <translation>Výchozí režim úprav</translation>
    </message>
    <message>
        <location filename="retext.py" line="499"/>
        <source>Search</source>
        <translation>Najít</translation>
    </message>
    <message>
        <location filename="retext.py" line="503"/>
        <source>Case sensitively</source>
        <translation>Rozlišovat velikost písmen</translation>
    </message>
    <message>
        <location filename="retext.py" line="526"/>
        <source>You have neither Markdown nor Docutils modules installed!</source>
        <translation>Nemáte nainstalován modul Markdown, ani Docutils!</translation>
    </message>
    <message>
        <location filename="retext.py" line="990"/>
        <source>HTML files</source>
        <translation>Soubory HTML</translation>
    </message>
    <message>
        <location filename="retext.py" line="1346"/>
        <source>Author: Dmitry Shachnev, 2011</source>
        <translation>Autor: Dmitry Shachnev, 2011</translation>
    </message>
    <message>
        <location filename="retext.py" line="1346"/>
        <source>Website</source>
        <translation>Webové stránky</translation>
    </message>
    <message>
        <location filename="retext.py" line="1346"/>
        <source>Markdown syntax</source>
        <translation>Syntax Markdownu</translation>
    </message>
    <message>
        <location filename="retext.py" line="1346"/>
        <source>ReST syntax</source>
        <translation>Syntax ReST</translation>
    </message>
    <message>
        <location filename="retext.py" line="987"/>
        <source>ReStructuredText files</source>
        <translation>Soubory ReStructuredText</translation>
    </message>
    <message>
        <location filename="retext.py" line="993"/>
        <source>Markdown files</source>
        <translation>Soubory Markdown</translation>
    </message>
    <message>
        <location filename="retext.py" line="1346"/>
        <source>Simple but powerful editor for Markdown and ReStructuredText</source>
        <translation>Jednoduchý, a přitom mocný editor pro Markdown a ReStructuredText</translation>
    </message>
    <message>
        <location filename="retext.py" line="1411"/>
        <source>Could not parse file contents, check if you have the necessary module installed!</source>
        <translation>Nepodařila se syntaktická kontrola obsahu, zkontrolujte, zda máte nainstalován nezbytný modul!</translation>
    </message>
    <message>
        <location filename="retext.py" line="929"/>
        <source>Select one or several files to open</source>
        <translation>Vyberte jeden nebo více souborů k otevření</translation>
    </message>
    <message>
        <location filename="retext.py" line="339"/>
        <source>Get help online</source>
        <translation>Získejte nápovědu online</translation>
    </message>
    <message>
        <location filename="retext.py" line="802"/>
        <source>Show directory</source>
        <translation>Zobrazit složku</translation>
    </message>
    <message>
        <location filename="retext.py" line="807"/>
        <source>Webpages generator is not installed!</source>
        <translation>Generátor webových stránek není nainstalován!</translation>
    </message>
    <message>
        <location filename="retext.py" line="1008"/>
        <source>Cannot save to file because it is read-only!</source>
        <translation>Nelze uložit, protože soubor je pouze pro čtení!</translation>
    </message>
    <message>
        <location filename="retext.py" line="1227"/>
        <source>Authentification failed, please check your internet connection!</source>
        <translation>Autentizace selhala, prosím, zkontrolujte své připojení k Internetu!</translation>
    </message>
    <message>
        <location filename="retext.py" line="368"/>
        <source>Bold</source>
        <translation>Tučné</translation>
    </message>
    <message>
        <location filename="retext.py" line="369"/>
        <source>Italic</source>
        <translation>Kurzíva</translation>
    </message>
    <message>
        <location filename="retext.py" line="370"/>
        <source>Underline</source>
        <translation>Podtržené</translation>
    </message>
    <message>
        <location filename="retext.py" line="461"/>
        <source>Formatting</source>
        <translation>Formátování</translation>
    </message>
    <message>
        <location filename="retext.py" line="344"/>
        <source>About %s</source>
        <translation>O %s</translation>
    </message>
    <message>
        <location filename="retext.py" line="327"/>
        <source>Use WebKit renderer</source>
        <translation>Použít k vykreslování WebKit</translation>
    </message>
    <message>
        <location filename="retext.py" line="1151"/>
        <source>Failed to execute the command:</source>
        <translation>Nepodařilo se spustit příkaz:</translation>
    </message>
</context>
</TS>
